# skil-client
Endpoints API for different services in SKIL

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.2.0-rc1
- Package version: 1.2.1.1
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import skil_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import skil_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import skil_client
from skil_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = skil_client.Configuration()
configuration.api_key['authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['authorization'] = 'Bearer'

# create an instance of the API class
api_instance = skil_client.DefaultApi(skil_client.ApiClient(configuration))

try:
    # Tells how many retraining examples have labels associated with them.
    api_response = api_instance.accumulated_results()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->accumulated_results: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:9008*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**accumulated_results**](docs/DefaultApi.md#accumulated_results) | **GET** /accumulatedresults | Tells how many retraining examples have labels associated with them.
*DefaultApi* | [**add_credentials**](docs/DefaultApi.md#add_credentials) | **POST** /resources/credentials | Adds credentials
*DefaultApi* | [**add_evaluation_result**](docs/DefaultApi.md#add_evaluation_result) | **POST** /rpc/{modelHistoryServerId}/model/revisions/evaluations/ | Adds an evaluation result
*DefaultApi* | [**add_example_for_batch**](docs/DefaultApi.md#add_example_for_batch) | **POST** /rpc/{modelHistoryServerId}/model/exampleForBatch | Adds a number of examples to a minibatch ID given an AddExampleRequest.
*DefaultApi* | [**add_example_to_minibatch**](docs/DefaultApi.md#add_example_to_minibatch) | **POST** /rpc/{modelHistoryServerId}/model/example | Adds an example to a minibatch
*DefaultApi* | [**add_experiment**](docs/DefaultApi.md#add_experiment) | **POST** /rpc/{modelHistoryServerId}/experiment | Add an experiment, given an experiment entity
*DefaultApi* | [**add_feedback_binary**](docs/DefaultApi.md#add_feedback_binary) | **POST** /feedback/{id}/{type} | 
*DefaultApi* | [**add_feedback_json**](docs/DefaultApi.md#add_feedback_json) | **POST** /feedback/{id}/json | Gets the retraining feedback for the given batch ID.
*DefaultApi* | [**add_minibatch**](docs/DefaultApi.md#add_minibatch) | **POST** /rpc/{modelHistoryServerId}/model/minibatch | Adds a minibatch
*DefaultApi* | [**add_model_feedback**](docs/DefaultApi.md#add_model_feedback) | **POST** /rpc/{modelHistoryServerId}/model/feedback | Adds an evaluation feedback to the model against a given minibatch id.
*DefaultApi* | [**add_model_history**](docs/DefaultApi.md#add_model_history) | **POST** /rpc/{modelHistoryServerId}/modelhistory | Add a model history / workspace
*DefaultApi* | [**add_model_instance**](docs/DefaultApi.md#add_model_instance) | **POST** /rpc/{modelHistoryServerId}/model | Adds a model
*DefaultApi* | [**add_resource**](docs/DefaultApi.md#add_resource) | **POST** /resources/add/resource | Adds a resource
*DefaultApi* | [**add_resource_group**](docs/DefaultApi.md#add_resource_group) | **POST** /resources/add/group | Adds a resource group
*DefaultApi* | [**add_resource_to_group**](docs/DefaultApi.md#add_resource_to_group) | **GET** /resources/add/resourcetogroup/{resourceGroupId}/{resourceId} | Adds a resource to a resource group
*DefaultApi* | [**aggregate_model_results**](docs/DefaultApi.md#aggregate_model_results) | **POST** /rpc/{modelHistoryServerId}/model/aggregateresults | Aggregates the evaluaition results of a model instance, based on the evaluation type
*DefaultApi* | [**change_user_password**](docs/DefaultApi.md#change_user_password) | **POST** /user/{userId}/password | Change user&#39;s password
*DefaultApi* | [**classify**](docs/DefaultApi.md#classify) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/classify | Use the deployed model to classify the input
*DefaultApi* | [**classifyarray**](docs/DefaultApi.md#classifyarray) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/classifyarray | Same as /classify but returns the output as Base64NDArrayBody
*DefaultApi* | [**classifyimage**](docs/DefaultApi.md#classifyimage) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/classifyimage | Use the deployed model to classify the input, using input image file from multipart form data.
*DefaultApi* | [**clear_state**](docs/DefaultApi.md#clear_state) | **POST** /clear | Clears the accumulated data for retraining.
*DefaultApi* | [**create_job**](docs/DefaultApi.md#create_job) | **POST** /jobs/{jobIdOrType} | Create a job
*DefaultApi* | [**create_model_history**](docs/DefaultApi.md#create_model_history) | **POST** /rpc/{modelHistoryServerId}/model/revisions | Creates model History
*DefaultApi* | [**delete_credentials_by_id**](docs/DefaultApi.md#delete_credentials_by_id) | **DELETE** /resources/credentials/{credentialId} | Delete credentials given an ID
*DefaultApi* | [**delete_experiment**](docs/DefaultApi.md#delete_experiment) | **DELETE** /rpc/{modelHistoryServerId}/experiment/{experimentID} | Deletes an experiment, given an experiment entity
*DefaultApi* | [**delete_job_by_id**](docs/DefaultApi.md#delete_job_by_id) | **DELETE** /jobs/{jobIdOrType} | Deletes a job given its ID
*DefaultApi* | [**delete_model**](docs/DefaultApi.md#delete_model) | **DELETE** /deployment/{deploymentId}/model/{modelId} | Delete a model by deployment and model id
*DefaultApi* | [**delete_model_history**](docs/DefaultApi.md#delete_model_history) | **DELETE** /rpc/{modelHistoryServerId}/modelhistory/{modelHistoryID} | Deletes a model history / workspace, given its ID
*DefaultApi* | [**delete_model_instance**](docs/DefaultApi.md#delete_model_instance) | **DELETE** /rpc/{modelHistoryServerId}/model/{modelInstanceID} | Deletes a model instance, given its ID
*DefaultApi* | [**delete_resource_by_id**](docs/DefaultApi.md#delete_resource_by_id) | **DELETE** /resources/remove/resource/{resourceId} | Delete the resource with the specified resource ID
*DefaultApi* | [**delete_resource_from_group**](docs/DefaultApi.md#delete_resource_from_group) | **GET** /resources/remove/resourcefromgroup/{resourceGroupId}/{resourceId} | Removes a resource from a resource group
*DefaultApi* | [**delete_resource_group_by_id**](docs/DefaultApi.md#delete_resource_group_by_id) | **DELETE** /resources/remove/group/{resourceGroupId} | Delete the resource group with the specified resource group ID
*DefaultApi* | [**deploy_model**](docs/DefaultApi.md#deploy_model) | **POST** /deployment/{deploymentId}/model | Deploy a model in a deployment group.
*DefaultApi* | [**deployment_create**](docs/DefaultApi.md#deployment_create) | **POST** /deployment | Create a new deployment group.
*DefaultApi* | [**deployment_delete**](docs/DefaultApi.md#deployment_delete) | **DELETE** /deployment/{deploymentId} | Delete a deployment by id
*DefaultApi* | [**deployment_get**](docs/DefaultApi.md#deployment_get) | **GET** /deployment/{deploymentId} | Get a deployment details by id
*DefaultApi* | [**deployments**](docs/DefaultApi.md#deployments) | **GET** /deployments | Get a list of deployments
*DefaultApi* | [**detectobjects**](docs/DefaultApi.md#detectobjects) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/detectobjects | Detect the objects, given a (input) prediction request
*DefaultApi* | [**download_job_output_file**](docs/DefaultApi.md#download_job_output_file) | **POST** /jobs/{jobId}/outputfile | Download the output file from the job&#39;s execution. This will ONLY work if the job&#39;s run status is &#39;COMPLETE&#39;.
*DefaultApi* | [**generate_auth_token**](docs/DefaultApi.md#generate_auth_token) | **POST** /auth/token | Generate new auth token
*DefaultApi* | [**get_all_jobs**](docs/DefaultApi.md#get_all_jobs) | **GET** /jobs | Get a list of all available jobs
*DefaultApi* | [**get_array**](docs/DefaultApi.md#get_array) | **POST** /array/{arrayType} | Get the memory mapped array based on the array type.
*DefaultApi* | [**get_array_indices**](docs/DefaultApi.md#get_array_indices) | **POST** /array/indices/{arrayType} | Get the memory mapped array indices based on the array type.
*DefaultApi* | [**get_array_range**](docs/DefaultApi.md#get_array_range) | **POST** /array/range/{from}/{to}/{arrayType} | Get the memory mapped array within a range based on the array type.
*DefaultApi* | [**get_auth_policy**](docs/DefaultApi.md#get_auth_policy) | **GET** /auth/policy | Get auth policy
*DefaultApi* | [**get_best_model_among_model_ids**](docs/DefaultApi.md#get_best_model_among_model_ids) | **POST** /rpc/{modelHistoryServerId}/model/best | Gets the best model among the given model instance IDs, based on the evaluation type and column metric
*DefaultApi* | [**get_credentials_by_id**](docs/DefaultApi.md#get_credentials_by_id) | **GET** /resources/credentials/{credentialId} | Get credentials given an ID
*DefaultApi* | [**get_current_model**](docs/DefaultApi.md#get_current_model) | **GET** /model | Returns the current model being used for retraining.
*DefaultApi* | [**get_evaluation_for_model_id**](docs/DefaultApi.md#get_evaluation_for_model_id) | **GET** /rpc/{modelHistoryServerId}/model/revisions/evaluations/{modelInstanceID} | Gets the list of evaluation results entity, given a model instance ID
*DefaultApi* | [**get_examples_for_minibatch**](docs/DefaultApi.md#get_examples_for_minibatch) | **GET** /rpc/{modelHistoryServerId}/model/example/{minibatchId} | Gets all the examples for a minibatch ID
*DefaultApi* | [**get_experiment**](docs/DefaultApi.md#get_experiment) | **GET** /rpc/{modelHistoryServerId}/experiment/{experimentID} | Obtain an experiment&#39;s details, given its ID
*DefaultApi* | [**get_experiments_for_model_history**](docs/DefaultApi.md#get_experiments_for_model_history) | **GET** /rpc/{modelHistoryServerId}/experiments/{modelHistoryID} | Obtain all experiments for a model history / workspace
*DefaultApi* | [**get_job_by_id**](docs/DefaultApi.md#get_job_by_id) | **GET** /jobs/{jobIdOrType} | Get a job by its ID
*DefaultApi* | [**get_last_evaluation**](docs/DefaultApi.md#get_last_evaluation) | **GET** /lastevaluation | Get the last evaluation specifications from the current model.
*DefaultApi* | [**get_minibatch**](docs/DefaultApi.md#get_minibatch) | **GET** /rpc/{modelHistoryServerId}/model/minibatch/{minibatchId} | Gets a minibatch for the model
*DefaultApi* | [**get_model_history**](docs/DefaultApi.md#get_model_history) | **GET** /rpc/{modelHistoryServerId}/model/revision/{modelHistoryID} | Gets a model history, given its ID
*DefaultApi* | [**get_model_instance**](docs/DefaultApi.md#get_model_instance) | **GET** /rpc/{modelHistoryServerId}/model/{modelInstanceID} | Gets a model instance, given its ID
*DefaultApi* | [**get_models_for_experiment**](docs/DefaultApi.md#get_models_for_experiment) | **GET** /rpc/{modelHistoryServerId}/experiment/{experimentID}/models | Obtain a list of all the models for an experiment
*DefaultApi* | [**get_resource_by_id**](docs/DefaultApi.md#get_resource_by_id) | **GET** /resources/resource/{resourceId} | Get the resource with the specified resource ID
*DefaultApi* | [**get_resource_by_sub_type**](docs/DefaultApi.md#get_resource_by_sub_type) | **GET** /resources/resources/subtype/{resourceSubType} | Get all the resources with the specified resource subtype
*DefaultApi* | [**get_resource_by_type**](docs/DefaultApi.md#get_resource_by_type) | **GET** /resources/resources/type/{resourceType} | Get all the resources with the specified resource type
*DefaultApi* | [**get_resource_details_by_id**](docs/DefaultApi.md#get_resource_details_by_id) | **GET** /resources/details/{resourceId} | Get the resource details with the specified resource ID
*DefaultApi* | [**get_resource_group_by_id**](docs/DefaultApi.md#get_resource_group_by_id) | **GET** /resources/group/{resourceGroupId} | Get the resource group with the specified resource group ID
*DefaultApi* | [**get_resource_groups**](docs/DefaultApi.md#get_resource_groups) | **GET** /resources/groups | Get a list of all the resource groups
*DefaultApi* | [**get_resources**](docs/DefaultApi.md#get_resources) | **GET** /resources/resources | A list of all known/registered resources, of all types
*DefaultApi* | [**get_resources_from_group**](docs/DefaultApi.md#get_resources_from_group) | **GET** /resources/group/{resourceGroupId}/resources | Get all resources from a resource group
*DefaultApi* | [**get_roles**](docs/DefaultApi.md#get_roles) | **GET** /security/roles | Get all roles.
*DefaultApi* | [**get_user**](docs/DefaultApi.md#get_user) | **GET** /user/{userId} | Get a user by user ID
*DefaultApi* | [**get_user_auth_tokens**](docs/DefaultApi.md#get_user_auth_tokens) | **GET** /auth/{userId}/tokens | Get auth tokens for a user.
*DefaultApi* | [**get_users**](docs/DefaultApi.md#get_users) | **GET** /security/users | Get all users.
*DefaultApi* | [**is_training**](docs/DefaultApi.md#is_training) | **GET** /istraining | Get the retraining status
*DefaultApi* | [**jsonarray**](docs/DefaultApi.md#jsonarray) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/jsonarray | Run inference on the input and returns it as a JsonArrayResponse
*DefaultApi* | [**knn**](docs/DefaultApi.md#knn) | **POST** /endpoints/{deploymentName}/knn/{knnName}/{versionName}/knn | Runs knn on the given index with the given k
*DefaultApi* | [**knnnew**](docs/DefaultApi.md#knnnew) | **POST** /endpoints/{deploymentName}/knn/{knnName}/{versionName}/knnnew | Run a k nearest neighbors search on a NEW data point
*DefaultApi* | [**list_all_experiments**](docs/DefaultApi.md#list_all_experiments) | **GET** /rpc/{modelHistoryServerId}/experiments | List all of the experiments in every model history / workspace
*DefaultApi* | [**logfilepath**](docs/DefaultApi.md#logfilepath) | **GET** /endpoints/{deploymentName}/model/{modelName}/{versionName}/logfilepath | Get logs file path
*DefaultApi* | [**login**](docs/DefaultApi.md#login) | **POST** /login | Post JSON credentials and obtain a JWT authorization token.
*DefaultApi* | [**logs**](docs/DefaultApi.md#logs) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/logs | Get logs
*DefaultApi* | [**meta_get**](docs/DefaultApi.md#meta_get) | **GET** /endpoints/{deploymentName}/model/{modelName}/{versionName}/meta | this method can be used to get the meta data for the current model which set to the server
*DefaultApi* | [**meta_post**](docs/DefaultApi.md#meta_post) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/meta | This method can be used to set meta data for the current model which is set to the server
*DefaultApi* | [**model_state_change**](docs/DefaultApi.md#model_state_change) | **POST** /deployment/{deploymentId}/model/{modelId}/state | Modify the state (start/stop) of a deployed model
*DefaultApi* | [**models**](docs/DefaultApi.md#models) | **GET** /deployment/{deploymentId}/models | Retrieve a list of all the deployed models given a deployment id
*DefaultApi* | [**modelset**](docs/DefaultApi.md#modelset) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/modelset | Set the model to be served
*DefaultApi* | [**modelupdate**](docs/DefaultApi.md#modelupdate) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/modelupdate | Update the model to be served
*DefaultApi* | [**multiclassify**](docs/DefaultApi.md#multiclassify) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/multiclassify | Represents all of the labels for a given classification
*DefaultApi* | [**multipredict**](docs/DefaultApi.md#multipredict) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/multipredict | Get the output from the network, based on the given INDArray[] input
*DefaultApi* | [**multipredictimage**](docs/DefaultApi.md#multipredictimage) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/multipredictimage | Get the output from the network using the given image file using the /multipredict endpoint&#39;s method
*DefaultApi* | [**num_revisions**](docs/DefaultApi.md#num_revisions) | **GET** /numrevisions | Gets the number of retrained models written with retraining.
*DefaultApi* | [**predict**](docs/DefaultApi.md#predict) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/predict | Run inference on the input array.
*DefaultApi* | [**predict_error**](docs/DefaultApi.md#predict_error) | **POST** /{operation}/{inputType}/error | Runs inference and find invalid rows based on the input data. Output is defined relative to the output adapter specified.
*DefaultApi* | [**predict_v2_file**](docs/DefaultApi.md#predict_v2_file) | **POST** /{operation}/{inputTypeFile} | Runs inference based on the input data. Output is defined relative to the output adapter specified.
*DefaultApi* | [**predict_v2_json**](docs/DefaultApi.md#predict_v2_json) | **POST** /{operation}/{inputTypeJson} | Runs inference based on the input data. Output is defined relative to the output adapter specified.
*DefaultApi* | [**predictimage**](docs/DefaultApi.md#predictimage) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/predictimage | Run inference on the input array, using input image file from multipart form data.
*DefaultApi* | [**predictwithpreprocess**](docs/DefaultApi.md#predictwithpreprocess) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/predictwithpreprocess | Preprocesses the input and run inference on it
*DefaultApi* | [**predictwithpreprocessjson**](docs/DefaultApi.md#predictwithpreprocessjson) | **POST** /endpoints/{deploymentName}/model/{modelName}/{versionName}/predictwithpreprocessjson | Preprocesses the input and run inference on it and returns it as a JsonArrayResponse
*DefaultApi* | [**raw_predict_binary**](docs/DefaultApi.md#raw_predict_binary) | **POST** /raw/{inputType}/{outputType} | Runs inference based on the input data. Output is defined relative to the output adapter specified.
*DefaultApi* | [**refresh_job_status**](docs/DefaultApi.md#refresh_job_status) | **GET** /jobs/{jobId}/refresh | Refresh the remote job status. Can be used for monitoring.
*DefaultApi* | [**register_user**](docs/DefaultApi.md#register_user) | **POST** /user/register | Register a new user
*DefaultApi* | [**reimport_model**](docs/DefaultApi.md#reimport_model) | **POST** /deployment/{deploymentId}/model/{modelId} | Reimport a model to a previous deployed model in a deployment
*DefaultApi* | [**revoke_user_token**](docs/DefaultApi.md#revoke_user_token) | **DELETE** /auth/token/{tokenId} | Revoke a user token.
*DefaultApi* | [**rollback**](docs/DefaultApi.md#rollback) | **POST** /rollback/{index} | Rollback to a previous revision of the model.
*DefaultApi* | [**run_a_job**](docs/DefaultApi.md#run_a_job) | **POST** /jobs/{jobId}/run | Start running an (already created) job on the remote resource
*DefaultApi* | [**transform_csv**](docs/DefaultApi.md#transform_csv) | **POST** /endpoints/{deploymentName}/datavec/{transformName}/{versionName}/transform | Takes a BatchCSVRecord and returns the transformed array as BatchCSVRecord
*DefaultApi* | [**transformarray**](docs/DefaultApi.md#transformarray) | **POST** /endpoints/{deploymentName}/datavec/{transformName}/{versionName}/transformarray | Takes a batch input arrays and transforms it
*DefaultApi* | [**transformimage**](docs/DefaultApi.md#transformimage) | **POST** /endpoints/{deploymentName}/datavec/{imageTransformName}/{versionName}/transformimage | Takes multiple multipart image file to transform and returns Base64NDArrayBody
*DefaultApi* | [**transformincremental_csv**](docs/DefaultApi.md#transformincremental_csv) | **POST** /endpoints/{deploymentName}/datavec/{transformName}/{versionName}/transformincremental | Takes SingleCSVRecord as input and returns the transformed array as SingleCSVRecord
*DefaultApi* | [**transformincrementalarray**](docs/DefaultApi.md#transformincrementalarray) | **POST** /endpoints/{deploymentName}/datavec/{transformName}/{versionName}/transformincrementalarray | Same as /transformincremental but returns Base64NDArrayBody.
*DefaultApi* | [**transformincrementalimage**](docs/DefaultApi.md#transformincrementalimage) | **POST** /endpoints/{deploymentName}/datavec/{imageTransformName}/{versionName}/transformincrementalimage | Takes a single multipart image file to transform and returns Base64NDArrayBody
*DefaultApi* | [**transformprocess_get**](docs/DefaultApi.md#transformprocess_get) | **GET** /endpoints/{deploymentName}/datavec/{transformName}/{versionName}/transformprocess | Gets the JSON string of the deployed transform process (CSV or Image)
*DefaultApi* | [**transformprocess_post**](docs/DefaultApi.md#transformprocess_post) | **POST** /endpoints/{deploymentName}/datavec/{transformName}/{versionName}/transformprocess | Sets the deployed (CSV or Image) transform process through the provided JSON string
*DefaultApi* | [**update_auth_policy**](docs/DefaultApi.md#update_auth_policy) | **PUT** /auth/policy | Update auth policy
*DefaultApi* | [**update_best_model_for_experiment**](docs/DefaultApi.md#update_best_model_for_experiment) | **POST** /rpc/{modelHistoryServerId}/experiment/best | Updates the best model for an experiment
*DefaultApi* | [**update_experiment**](docs/DefaultApi.md#update_experiment) | **PUT** /rpc/{modelHistoryServerId}/experiment/{experimentID} | Updates an experiment, given an experiment entity
*DefaultApi* | [**update_model_history**](docs/DefaultApi.md#update_model_history) | **POST** /rpc/{modelHistoryServerId}/modelhistory/{modelHistoryID} | Update a model history / workspace
*DefaultApi* | [**update_user**](docs/DefaultApi.md#update_user) | **PUT** /user | Update a user
*DefaultApi* | [**upload**](docs/DefaultApi.md#upload) | **POST** /api/upload/model | Upload a model file to SKIL for import.


## Documentation For Models

 - [AccumulatedResults](docs/AccumulatedResults.md)
 - [AddCredentialsRequest](docs/AddCredentialsRequest.md)
 - [AddExampleRequest](docs/AddExampleRequest.md)
 - [AddModelHistoryRequest](docs/AddModelHistoryRequest.md)
 - [AddResourceRequest](docs/AddResourceRequest.md)
 - [AggregatePrediction](docs/AggregatePrediction.md)
 - [AuthPolicy](docs/AuthPolicy.md)
 - [AzureStorageResourceDetails](docs/AzureStorageResourceDetails.md)
 - [Base64NDArrayBody](docs/Base64NDArrayBody.md)
 - [Base64NDArrayBodyKNN](docs/Base64NDArrayBodyKNN.md)
 - [BatchCSVRecord](docs/BatchCSVRecord.md)
 - [BatchRecord](docs/BatchRecord.md)
 - [BestModel](docs/BestModel.md)
 - [ChangePasswordRequest](docs/ChangePasswordRequest.md)
 - [ClassificationResult](docs/ClassificationResult.md)
 - [CreateDeploymentRequest](docs/CreateDeploymentRequest.md)
 - [CreateJobRequest](docs/CreateJobRequest.md)
 - [DataProcResourceDetails](docs/DataProcResourceDetails.md)
 - [DeploymentObjects](docs/DeploymentObjects.md)
 - [DeploymentResponse](docs/DeploymentResponse.md)
 - [DetectedObject](docs/DetectedObject.md)
 - [DetectionResult](docs/DetectionResult.md)
 - [DownloadOutputFileRequest](docs/DownloadOutputFileRequest.md)
 - [EMRResourceDetails](docs/EMRResourceDetails.md)
 - [EvaluationResultsEntity](docs/EvaluationResultsEntity.md)
 - [ExampleEntity](docs/ExampleEntity.md)
 - [ExperimentEntity](docs/ExperimentEntity.md)
 - [FeedbackResponse](docs/FeedbackResponse.md)
 - [FileUpload](docs/FileUpload.md)
 - [FileUploadList](docs/FileUploadList.md)
 - [GoogleStorageResourceDetails](docs/GoogleStorageResourceDetails.md)
 - [HDFSResourceDetails](docs/HDFSResourceDetails.md)
 - [HDInsightResourceDetails](docs/HDInsightResourceDetails.md)
 - [INDArray](docs/INDArray.md)
 - [ImageTransformProcess](docs/ImageTransformProcess.md)
 - [ImportModelRequest](docs/ImportModelRequest.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [JobEntity](docs/JobEntity.md)
 - [JsonArrayResponse](docs/JsonArrayResponse.md)
 - [LogBatch](docs/LogBatch.md)
 - [LogRequest](docs/LogRequest.md)
 - [LoginRequest](docs/LoginRequest.md)
 - [LoginResponse](docs/LoginResponse.md)
 - [MetaData](docs/MetaData.md)
 - [MinibatchEntity](docs/MinibatchEntity.md)
 - [ModelEntity](docs/ModelEntity.md)
 - [ModelFeedBackRequest](docs/ModelFeedBackRequest.md)
 - [ModelHistoryEntity](docs/ModelHistoryEntity.md)
 - [ModelInstanceEntity](docs/ModelInstanceEntity.md)
 - [ModelResponse](docs/ModelResponse.md)
 - [ModelStatus](docs/ModelStatus.md)
 - [MultiClassClassificationResult](docs/MultiClassClassificationResult.md)
 - [MultiPredictRequest](docs/MultiPredictRequest.md)
 - [MultiPredictResponse](docs/MultiPredictResponse.md)
 - [NearestNeighborRequest](docs/NearestNeighborRequest.md)
 - [NearestNeighborsResult](docs/NearestNeighborsResult.md)
 - [NearestNeighborsResults](docs/NearestNeighborsResults.md)
 - [NewDeployment](docs/NewDeployment.md)
 - [Prediction](docs/Prediction.md)
 - [Resource](docs/Resource.md)
 - [ResourceCredentials](docs/ResourceCredentials.md)
 - [ResourceGroup](docs/ResourceGroup.md)
 - [RetrainingStatus](docs/RetrainingStatus.md)
 - [RevisionsWritten](docs/RevisionsWritten.md)
 - [Role](docs/Role.md)
 - [RollbackStatus](docs/RollbackStatus.md)
 - [S3ResourceDetails](docs/S3ResourceDetails.md)
 - [SetState](docs/SetState.md)
 - [SingleCSVRecord](docs/SingleCSVRecord.md)
 - [SingleRecord](docs/SingleRecord.md)
 - [Token](docs/Token.md)
 - [TokenGenerateRequest](docs/TokenGenerateRequest.md)
 - [TransformProcess](docs/TransformProcess.md)
 - [UpdateBestModel](docs/UpdateBestModel.md)
 - [User](docs/User.md)
 - [YARNResourceDetails](docs/YARNResourceDetails.md)


## Documentation For Authorization


## api_key

- **Type**: API key
- **API key parameter name**: authorization
- **Location**: HTTP header


## Author



